# Introduction

This is a module used for document embeddings.

- `docembedder.py` serves as starting point object that will download from Google Cloud Storage the
  appropriate model checkpoint
- `src/` contains files used for training
- `examples/` Contains use cases. You may need to copy them to root for them work properly.
